summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorOliver Bolte <obo@openoffice.org>2003-10-20 12:06:51 +0000
committerOliver Bolte <obo@openoffice.org>2003-10-20 12:06:51 +0000
commit6c07e8f3694f6827715d66ea382bcb7bf540b888 (patch)
tree438280f0bc1037a608798001e0e864a4f9d797cc
parent401ec0f9dfcb023829b761fb8843eedb0d6bac7a (diff)
INTEGRATION: CWS sdk08 (1.1.74); FILE MERGED
2003/09/16 13:41:10 jsc 1.1.74.1: #111025# warning support
-rw-r--r--idlc/inc/idlc/errorhandler.hxx12
1 files changed, 7 insertions, 5 deletions
diff --git a/idlc/inc/idlc/errorhandler.hxx b/idlc/inc/idlc/errorhandler.hxx
index 532e760ef4c6..b176ecb65b7f 100644
--- a/idlc/inc/idlc/errorhandler.hxx
+++ b/idlc/inc/idlc/errorhandler.hxx
@@ -2,9 +2,9 @@
*
* $RCSfile: errorhandler.hxx,v $
*
- * $Revision: 1.1 $
+ * $Revision: 1.2 $
*
- * last change: $Author: jsc $ $Date: 2001-03-15 12:23:01 $
+ * last change: $Author: obo $ $Date: 2003-10-20 13:06:51 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -124,8 +124,9 @@ enum WarningCode
{
WIDL_EXPID_CONFLICT, // exception id conflict
WIDL_REQID_CONFLICT, // request id conflict
- WIDL_INHERIT_IDCONFLICT, // request id conflict inheritance tree
- WIDL_TYPE_IDENT_CONFLICT // type and identifier has equal names
+ WIDL_INHERIT_IDCONFLICT, // request id conflict inheritance tree
+ WIDL_TYPE_IDENT_CONFLICT, // type and identifier has equal names
+ WIDL_WRONG_NAMING_CONV // type or identifier doesn't fulfill the UNO naming convention
};
class ErrorHandler
@@ -138,11 +139,12 @@ public:
void error3(ErrorCode e, AstDeclaration* d1, AstDeclaration* d2, AstDeclaration* d3);
// Warning
+ void warning0(WarningCode e, const sal_Char* warningmsg);
void warning1(WarningCode e, AstDeclaration* d);
void warning2(WarningCode e, AstDeclaration* d1, AstDeclaration* d2);
// Report a syntax error in IDL input
- void syntaxError(ParseState state, sal_Int32 lineNumber, sal_Char* errmsg);
+ void syntaxError(ParseState state, sal_Int32 lineNumber, const sal_Char* errmsg);
// Report a name being used with different spellings
void nameCaseError(sal_Char *n, sal_Char *t);